
Wish
================================================================================

[![Build Status](https://travis-ci.org/boisgera/wish.svg?branch=master)](https://travis-ci.org/boisgera/wish)


**Selectable Return Values for Python**

Homepage: <http://boisgera.github.io/wish/>
